==> jasperserver-2.1.0-src.zip: jasperserver-2.1.0-src/jasperserver/jasperserver-api/metadata/src/main/java/com/jaspersoft/jasperserver/api/metadata/common/domain/ContentResource.java <==
/*
 * Copyright (C) 2005 - 2007 JasperSoft Corporation.  All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased a commercial license agreement from JasperSoft,
 * the following license terms apply:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as published by
 * the Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; and without the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see http://www.gnu.org/licenses/gpl.txt
 * or write to:
 *
 * Free Software Foundation, Inc.,
 * 59 Temple Place - Suite 330,
 * Boston, MA  USA  02111-1307
 */
package com.jaspersoft.jasperserver.api.metadata.common.domain;

import java.io.InputStream;
import java.util.List;

import com.jaspersoft.jasperserver.api.metadata.common.domain.Resource;

public interface ContentResource extends Resource
{
	String TYPE_PDF = "pdf";
	String TYPE_HTML = "html";
	String TYPE_XLS = "xls";
	String TYPE_RTF = "rtf";
	String TYPE_CSV = "csv";

	boolean hasData();

	InputStream getDataStream();

	void readData(InputStream is);

	byte[] getData();

	void setData(byte[] data);

	String getFileType();

	void setFileType(String fileType);

	boolean isReference();

	String getReferenceURI();

	void setReferenceURI(String referenceURI);

	public List getResources();

	public void setResources(List resources);

	public void addChildResource(ContentResource child);

}

==> jasperserver-3.5.0-src.zip: jasperserver-3.5.0-src/jasperserver/jasperserver-api/metadata/src/main/java/com/jaspersoft/jasperserver/api/metadata/common/domain/ContentResource.java <==
/*
 * Copyright (C) 2005 - 2007 JasperSoft Corporation.  All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased a commercial license agreement from JasperSoft,
 * the following license terms apply:
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as published by
 * the Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; and without the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see http://www.gnu.org/licenses/gpl.txt
 * or write to:
 *
 * Free Software Foundation, Inc.,
 * 59 Temple Place - Suite 330,
 * Boston, MA  USA  02111-1307
 */
package com.jaspersoft.jasperserver.api.metadata.common.domain;

import java.io.InputStream;
import java.util.List;

import com.jaspersoft.jasperserver.api.metadata.common.domain.Resource;

public interface ContentResource extends Resource
{
	String TYPE_PDF = "pdf";
	String TYPE_HTML = "html";
	String TYPE_XLS = "xls";
	String TYPE_RTF = "rtf";
	String TYPE_CSV = "csv";
	String TYPE_IMAGE = "img";//unspecified image type

	boolean hasData();

	InputStream getDataStream();

	void readData(InputStream is);

	byte[] getData();

	void setData(byte[] data);
	
	void setDataContainer(DataContainer dataContainer);
        
        public int getSize();

	String getFileType();

	void setFileType(String fileType);

	boolean isReference();

	String getReferenceURI();

	void setReferenceURI(String referenceURI);

	public List getResources();

	public void setResources(List resources);

	public void addChildResource(ContentResource child);

}
